\name{nlogpost4}
\alias{nlogpost4}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{
Negative log likelihood, metaflu model, version 4
}
\description{
Compared to nlogpost, this one uses a single beta and a single gamma for all studies, where
beta is the false-negative measurement error and gamma is the accessibility rate. Useful for 
simulation studies.
}
\usage{
nlogpost4(x, K, kap, counts)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{x}{
 Vector of transformed parameters
}
  \item{K}{
 pool size, as in \code{nlogpost}
}
  \item{kap}{
 overdispersion parameter, as in \code{nlogpost}
}
  \item{counts}{
 data, as in \code{nlogpost}
}
}
\details{
 A wrapper for \code{loglik} forcing one-dimensional beta and gamma settings.
}
\value{
 Negative log likelihood of input parameters at data provided.
}
\references{
Hao et al. 2012.
}
\author{
Michael Newton and Qiuling He
}

\examples{

## A little simulation.  Making G large (e.g. 10^6 or more ) helps to show
## consistency of the code.

theta <- 1/4
alpha <- 1/10
bb <- 1/5
gg <- 1/10
omega <- 1/2
nu <- 1/10
psi.true <- c(theta,alpha,bb,gg,omega,nu)
names(psi.true) <- c("theta","alpha","beta","gamma","omega","nu")

## Make null (not involved) and alternative (involved) 81-cell probabilities
pp.n <- pp.nul( theta, alpha, rep(bb,4), rep(gg,4), omega, nu, K=12, kap=20 )
pp.a <- pp.alt( theta, alpha, rep(bb,4), rep(gg,4), omega, nu, K=12, kap=20 )

## model
pp <- pp.n * (1-theta) + pp.a * theta

# simulated table
G <- 10^6 ## lot's more genes than a real genome!
simtab <- c( rmultinom(1,size=G, prob=pp) )

# fit the model
par0 <- c( runif(5, min=-1,max=1), 0 )  ## a random start; may need multiple tries to get MLE for given simulated data set
res <- nlminb( par0, nlogpost4, K=12, kap=20, counts=simtab )
psi.hat <- c( exp(res$par[1:5])/(1+exp(res$par[1:5]) ) , exp(res$par[6]) )

print( cbind( psi.true, psi.hat ) )  ## increase G or do multiple retries (par0's) of nlminb fixing simtab to find MLE given simtab

}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
